bh_skel_latex(){
	echo -e \
'\\documentclass{article}

\\usepackage[english]{babel}
\\usepackage[utf8]{inputenc}
\\usepackage[margin=1in]{geometry}

\\author{}
\\title{}

\\begin{document}
\\maketitle

\\end{document}'
}
